==> hbase-prefix-tree-0.99.0-sources.jar: org/apache/hadoop/hbase/codec/prefixtree/encode/EncoderPoolImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.codec.prefixtree.encode;

import java.io.OutputStream;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;

import org.apache.hadoop.classification.InterfaceAudience;

@InterfaceAudience.Private
public class EncoderPoolImpl implements EncoderPool {

  private BlockingQueue<PrefixTreeEncoder> unusedEncoders = 
      new LinkedBlockingQueue<PrefixTreeEncoder>();

  @Override
  public PrefixTreeEncoder checkOut(OutputStream outputStream, boolean includeMvccVersion) {
    PrefixTreeEncoder encoder = unusedEncoders.poll();
    if (encoder == null) {
      encoder = new PrefixTreeEncoder(outputStream, includeMvccVersion);
    } else {
      encoder.reset(outputStream, includeMvccVersion);
    }
    return encoder;
  }

  @Override
  public void checkIn(PrefixTreeEncoder encoder) {
    this.unusedEncoders.add(encoder);
  }
}

==> hbase-prefix-tree-1.1.9-sources.jar: org/apache/hadoop/hbase/codec/prefixtree/encode/EncoderPoolImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.codec.prefixtree.encode;

import java.io.OutputStream;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;

import org.apache.hadoop.hbase.classification.InterfaceAudience;

@InterfaceAudience.Private
public class EncoderPoolImpl implements EncoderPool {

  private BlockingQueue<PrefixTreeEncoder> unusedEncoders = 
      new LinkedBlockingQueue<PrefixTreeEncoder>();

  @Override
  public PrefixTreeEncoder checkOut(OutputStream outputStream, boolean includeMvccVersion) {
    PrefixTreeEncoder encoder = unusedEncoders.poll();
    if (encoder == null) {
      encoder = new PrefixTreeEncoder(outputStream, includeMvccVersion);
    } else {
      encoder.reset(outputStream, includeMvccVersion);
    }
    return encoder;
  }

  @Override
  public void checkIn(PrefixTreeEncoder encoder) {
    this.unusedEncoders.add(encoder);
  }
}
